@@ -15,3 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.algo.filtering.pandas.attr_value_repetition import filter
+
+import warnings
+
+warnings.warn("The attr_value_repetition filter package will be removed in a future release.")
