@@ -35,35 +35,38 @@ class EndpointDirection(Enum):
 
 class Parameters(Enum):
     TASK_WH = "task_wh"
+    SCREEN_SIZE_X = "screen_size_x"
+    SCREEN_SIZE_Y = "screen_size_y"
+    SCALING_FACTOR = "scaling_factor"
 
 
-def get_right_edge_coord(node, p, partial_counter, total_counter):
+def get_right_edge_coord(layout, node, p, partial_counter, total_counter):
     y_factor = partial_counter[EndpointDirection.RIGHT] / (total_counter[EndpointDirection.RIGHT] + 1.0)
-    new_x = p[0] + node.get_width()
+    new_x = p[0] + layout.get(node).get_width()
     new_y = p[1] + round(
-        node.get_height() * y_factor)
+        layout.get(node).get_height() * y_factor)
     return (new_x, new_y)
 
 
-def get_left_edge_coord(node, p, partial_counter, total_counter):
+def get_left_edge_coord(layout, node, p, partial_counter, total_counter):
     y_factor = partial_counter[EndpointDirection.LEFT] / (total_counter[EndpointDirection.LEFT] + 1.0)
     new_x = p[0]
     new_y = p[1] + round(
-        node.get_height() * y_factor)
+        layout.get(node).get_height() * y_factor)
     return (new_x, new_y)
 
 
-def get_top_edge_coord(node, p, partial_counter, total_counter):
+def get_top_edge_coord(layout, node, p, partial_counter, total_counter):
     x_factor = partial_counter[EndpointDirection.TOP] / (total_counter[EndpointDirection.TOP] + 1.0)
-    new_x = p[0] + round(node.get_width() * x_factor)
+    new_x = p[0] + round(layout.get(node).get_width() * x_factor)
     new_y = p[1]
     return (new_x, new_y)
 
 
-def get_bottom_edge_coord(node, p, partial_counter, total_counter):
+def get_bottom_edge_coord(layout, node, p, partial_counter, total_counter):
     x_factor = partial_counter[EndpointDirection.BOTTOM] / (total_counter[EndpointDirection.BOTTOM] + 1.0)
-    new_x = p[0] + round(node.get_width() * x_factor)
-    new_y = p[1] + node.get_height()
+    new_x = p[0] + round(layout.get(node).get_width() * x_factor)
+    new_y = p[1] + layout.get(node).get_height()
     return (new_x, new_y)
 
 
@@ -76,7 +79,10 @@ def apply(bpmn_graph, parameters=None):
     bpmn_graph
         BPMN graph
     parameters
-        Parameters of the algorithm
+        Parameters of the algorithm:
+        - Parameters.SCREEN_SIZE_X => target size of the screen in pixels (default 1920.0)
+        - Parameters.SCREEN_SIZE_Y => target size of the screen in pixels (default 1080.0)
+        - Parameters.SCALING_FACTOR => scaling factor of the layouting (defualt 2.5)
 
     Returns
     -------------
@@ -85,12 +91,18 @@ def apply(bpmn_graph, parameters=None):
     """
     from graphviz import Digraph
     from pm4py.visualization.common import save as gsave
+    from pm4py.visualization.common import svg_pos_parser
 
     if parameters is None:
         parameters = {}
 
+    screen_size_x = exec_utils.get_param_value(Parameters.SCREEN_SIZE_X, parameters, 1920.0)
+    screen_size_y = exec_utils.get_param_value(Parameters.SCREEN_SIZE_Y, parameters, 1080.0)
+    scaling_factor = exec_utils.get_param_value(Parameters.SCALING_FACTOR, parameters, 2.5)
+
     nodes = bpmn_graph.get_nodes()
     flows = bpmn_graph.get_flows()
+    layout = bpmn_graph.get_layout()
 
     filename_gv = tempfile.NamedTemporaryFile(suffix='.gv')
     filename_gv.close()
@@ -115,48 +127,54 @@ def apply(bpmn_graph, parameters=None):
 
     gsave.save(viz, filename_svg.name)
 
-    nodes_pos = {}
+    nodes_p, edges_p = svg_pos_parser.apply(filename_svg.name)
 
-    content = open(filename_svg.name, "r").read()
-    viz_nodes = content.split("class=\"node\">")[1:]
-    for node in viz_nodes:
-        this_id = node.split("<title>")[1].split("</title>")[0]
-        points = node.split("points=\"")[1].split("\"")[0]
-        nodes_pos[inv_nodes_dict[this_id]] = points
+    nodes_pos = {}
+    for node in nodes_p:
+        nodes_pos[inv_nodes_dict[node]] = nodes_p[node]["polygon"]
 
     endpoints_wh = exec_utils.get_param_value(Parameters.TASK_WH, parameters, 30)
     task_wh = exec_utils.get_param_value(Parameters.TASK_WH, parameters, 60)
 
     # add node positions to BPMN nodes
     for n in graph_nodes:
-        node_pos = nodes_pos[n].split(" ")[0].split(",")
+        node_pos = nodes_pos[n][0]
 
         pos_x = float(node_pos[0])
         pos_y = float(node_pos[1])
-        n.set_x(pos_x)
-        n.set_y(pos_y)
+        layout.get(n).set_x(pos_x)
+        layout.get(n).set_y(pos_y)
         if isinstance(n, BPMN.Task):
             this_width = min(round(2 * task_wh), round(2 * (len(n.get_name()) + 7) * task_wh / 22.0))
-            n.set_width(this_width)
-            n.set_height(task_wh)
+            layout.get(n).set_width(this_width)
+            layout.get(n).set_height(task_wh)
         elif isinstance(n, BPMN.StartEvent) or isinstance(n, BPMN.EndEvent):
-            n.set_width(endpoints_wh)
-            n.set_height(endpoints_wh)
+            layout.get(n).set_width(endpoints_wh)
+            layout.get(n).set_height(endpoints_wh)
         else:
-            n.set_width(task_wh)
-            n.set_height(task_wh)
+            layout.get(n).set_width(task_wh)
+            layout.get(n).set_height(task_wh)
 
-    max_x = max(1, max(abs(node.get_x()) for node in nodes))
-    max_y = max(1, max(abs(node.get_y()) for node in nodes))
-    different_x = len(set(node.get_x() for node in nodes))
-    different_y = len(set(node.get_y() for node in nodes))
+    max_x = max(1, max(abs(layout.get(node).get_x()) for node in nodes))
+    max_y = max(1, max(abs(layout.get(node).get_y()) for node in nodes))
+    different_x = len(set(layout.get(node).get_x() for node in nodes))
+    different_y = len(set(layout.get(node).get_y() for node in nodes))
 
-    stretch_fact_x = 2.5 * 1.25 * 1920.0 / max_x
-    stretch_fact_y = 2.5 * 1080.0 / max_y
+    stretch_fact_x = scaling_factor * 1.25 * screen_size_x / max_x
+    stretch_fact_y = scaling_factor * screen_size_y / max_y
 
     for node in nodes:
-        node.set_x(round(node.get_x() * stretch_fact_x))
-        node.set_y(round(node.get_y() * stretch_fact_y))
+        layout.get(node).set_x(round(layout.get(node).get_x() * stretch_fact_x))
+        layout.get(node).set_y(round(layout.get(node).get_y() * stretch_fact_y))
+
+    min_x = min(layout.get(node).get_x() for node in nodes)
+    min_y = min(layout.get(node).get_y() for node in nodes)
+
+    for node in nodes:
+        x_coord = layout.get(node).get_x() - min_x
+        y_coord = layout.get(node).get_y() - min_y
+        layout.get(node).set_x(x_coord)
+        layout.get(node).set_y(y_coord)
 
     outgoing_edges = dict()
     ingoing_edges = dict()
@@ -167,10 +185,10 @@ def apply(bpmn_graph, parameters=None):
         source = flow.get_source()
         target = flow.get_target()
 
-        x_src = source.get_x()
-        x_trg = target.get_x()
-        y_src = source.get_y()
-        y_trg = target.get_y()
+        x_src = layout.get(source).get_x()
+        x_trg = layout.get(target).get_x()
+        y_src = layout.get(source).get_y()
+        y_trg = layout.get(target).get_y()
 
         sources_dict[(x_src, y_src)] = source
         targets_dict[(x_trg, y_trg)] = target
@@ -302,13 +320,13 @@ def apply(bpmn_graph, parameters=None):
             dir = outgoing_edges[p1][p2]
             partial_counter[p1][dir] += 1
             if dir == EndpointDirection.RIGHT:
-                outgoing_edges[p1][p2] = get_right_edge_coord(node, p1, partial_counter[p1], total_counter[p1])
+                outgoing_edges[p1][p2] = get_right_edge_coord(layout, node, p1, partial_counter[p1], total_counter[p1])
             elif dir == EndpointDirection.LEFT:
-                outgoing_edges[p1][p2] = get_left_edge_coord(node, p1, partial_counter[p1], total_counter[p1])
+                outgoing_edges[p1][p2] = get_left_edge_coord(layout, node, p1, partial_counter[p1], total_counter[p1])
             elif dir == EndpointDirection.TOP:
-                outgoing_edges[p1][p2] = get_top_edge_coord(node, p1, partial_counter[p1], total_counter[p1])
+                outgoing_edges[p1][p2] = get_top_edge_coord(layout, node, p1, partial_counter[p1], total_counter[p1])
             elif dir == EndpointDirection.BOTTOM:
-                outgoing_edges[p1][p2] = get_bottom_edge_coord(node, p1, partial_counter[p1], total_counter[p1])
+                outgoing_edges[p1][p2] = get_bottom_edge_coord(layout, node, p1, partial_counter[p1], total_counter[p1])
     for p1 in ingoing_edges:
         node = targets_dict[p1]
         if p1 not in partial_counter:
@@ -318,13 +336,13 @@ def apply(bpmn_graph, parameters=None):
             dir = ingoing_edges[p1][p2]
             partial_counter[p1][dir] += 1
             if dir == EndpointDirection.RIGHT:
-                ingoing_edges[p1][p2] = get_right_edge_coord(node, p1, partial_counter[p1], total_counter[p1])
+                ingoing_edges[p1][p2] = get_right_edge_coord(layout, node, p1, partial_counter[p1], total_counter[p1])
             elif dir == EndpointDirection.LEFT:
-                ingoing_edges[p1][p2] = get_left_edge_coord(node, p1, partial_counter[p1], total_counter[p1])
+                ingoing_edges[p1][p2] = get_left_edge_coord(layout, node, p1, partial_counter[p1], total_counter[p1])
             elif dir == EndpointDirection.TOP:
-                ingoing_edges[p1][p2] = get_top_edge_coord(node, p1, partial_counter[p1], total_counter[p1])
+                ingoing_edges[p1][p2] = get_top_edge_coord(layout, node, p1, partial_counter[p1], total_counter[p1])
             elif dir == EndpointDirection.BOTTOM:
-                ingoing_edges[p1][p2] = get_bottom_edge_coord(node, p1, partial_counter[p1], total_counter[p1])
+                ingoing_edges[p1][p2] = get_bottom_edge_coord(layout, node, p1, partial_counter[p1], total_counter[p1])
 
     # order the left-entering ingoing edges better
     for p1 in ingoing_edges:
@@ -344,10 +362,10 @@ def apply(bpmn_graph, parameters=None):
 
         flow.del_waypoints()
 
-        x_src = source.get_x()
-        x_trg = target.get_x()
-        y_src = source.get_y()
-        y_trg = target.get_y()
+        x_src = layout.get(source).get_x()
+        x_trg = layout.get(target).get_x()
+        y_src = layout.get(source).get_y()
+        y_trg = layout.get(target).get_y()
         p1 = (x_src, y_src)
         p2 = (x_trg, y_trg)
 
